==> plotreset-0.3.1.tar.gz: plotreset-0.3.1/src/plotreset/defaults.py <==
colors = {
    "red_default": "tab:red",
    "blue_default": "tab:blue",
    "green_default": "tab:green",
    "orange_default": "tab:orange",
    "purple_default": "tab:purple",
    "brown_default": "tab:brown",
    "pink_default": "tab:pink",
    "gray_default": "tab:gray",
    "olive_default": "tab:olive",
    "cyan_default": "tab:cyan",
    "black_default": "black",
}

line_styles = {
    "solid": "-",
    "dashed": "--",
    "dotted": ":",
    "dashdot": "-.",
    "loosely dotted": (0, (1, 10)),
    "densely dotted": (0, (1, 1)),
    "loosely dashed": (0, (5, 10)),
    "densely dashed": (0, (5, 1)),
    "loosely dashdotted": (0, (3, 10, 1, 10)),
    "dashdotted": (0, (3, 1, 1, 1)),
    "densely dashdotted": (0, (3, 5, 1, 5)),
    "dashdotdotted": (0, (3, 5, 1, 5, 1, 5)),
    "loosely dashdotdotted": (0, (3, 10, 1, 10, 1, 10)),
    "densely dashdotdotted": (0, (3, 1, 1, 1, 1, 1)),
}

line_widths = {"thin": 1, "thick": 2, "thicker": 3, "thickest": 4}

markers = {
    "circle": "o",
    "square": "s",
    "triangle": "^",
    "plus": "+",
    "x": "x",
    "diamond": "D",
    "thin_diamond": "d",
    "pentagon": "p",
    "star": "*",
    "hexagon": "h",
    "hexagon2": "H",
    "plus_filled": "p",
    "x_filled": "x",
    "diamond_filled": "D",
    "thin_diamond_filled": "d",
    "pentagon_filled": "p",
    "star_filled": "*",
    "hexagon_filled": "h",
    "hexagon2_filled": "H",
}


marker_sizes = {
    "tiny": 3,
    "small": 6,
    "medium": 8,
    "large": 10,
    "big": 12,
    "huge": 16,
    "enormous": 20,
}

font_sizes = {
    "tiny": 8,
    "small": 10,
    "medium": 12,
    "large": 14,
    "big": 16,
    "huge": 18,
}

font_styles = {"normal": 0, "italic": 1, "oblique": 2}

==> plotreset-0.4.3.tar.gz: plotreset-0.4.3/src/plotreset/defaults.py <==
COLORS = {
    "red_default": "tab:red",
    "blue_default": "tab:blue",
    "green_default": "tab:green",
    "orange_default": "tab:orange",
    "purple_default": "tab:purple",
    "brown_default": "tab:brown",
    "pink_default": "tab:pink",
    "gray_default": "tab:gray",
    "olive_default": "tab:olive",
    "cyan_default": "tab:cyan",
    "black_default": "black",
}

LINE_STYLES = {
    "solid": "-",
    "dashed": "--",
    "dotted": ":",
    "dashdot": "-.",
    "loosely dotted": (0, (1, 10)),
    "densely dotted": (0, (1, 1)),
    "loosely dashed": (0, (5, 10)),
    "densely dashed": (0, (5, 1)),
    "loosely dashdotted": (0, (3, 10, 1, 10)),
    "dashdotted": (0, (3, 1, 1, 1)),
    "densely dashdotted": (0, (3, 5, 1, 5)),
    "dashdotdotted": (0, (3, 5, 1, 5, 1, 5)),
    "loosely dashdotdotted": (0, (3, 10, 1, 10, 1, 10)),
    "densely dashdotdotted": (0, (3, 1, 1, 1, 1, 1)),
}

LINE_WIDTHS = {"thin": 1, "thick": 2, "thicker": 3, "thickest": 4}

MARKERS = {
    "circle": "o",
    "square": "s",
    "triangle": "^",
    "plus": "+",
    "x": "x",
    "diamond": "D",
    "thin_diamond": "d",
    "pentagon": "p",
    "star": "*",
    "hexagon": "h",
    "hexagon2": "H",
    "plus_filled": "p",
    "x_filled": "x",
    "diamond_filled": "D",
    "thin_diamond_filled": "d",
    "pentagon_filled": "p",
    "star_filled": "*",
    "hexagon_filled": "h",
    "hexagon2_filled": "H",
}


MARKER_SIZES = {
    "tiny": 3,
    "small": 6,
    "medium": 8,
    "large": 10,
    "big": 12,
    "huge": 16,
    "enormous": 20,
}

FONT_SIZES = {
    "tiny": 8,
    "small": 10,
    "medium": 12,
    "large": 14,
    "big": 16,
    "huge": 18,
}

font_styles = {"normal": 0, "italic": 1, "oblique": 2}
